@@ -21,9 +21,16 @@ module.exports = function(config) {
         'node_modules/angular-messages/angular-messages.js',
         'node_modules/angular-animate/angular-animate.js',
         'node_modules/angular-sanitize/angular-sanitize.js',
+        'node_modules/angular-material/angular-material.js',
+        'node_modules/@cgross/angular-notify/dist/angular-notify.js',
+        'node_modules/angular-visjs/angular-vis.js',
+        'node_modules/angular-uuid/angular-uuid.js',
+        'node_modules/file-saver/FileSaver.js',
+        'node_modules/vis/dist/vis.js',
+        'node_modules/js-yaml/dist/js-yaml.js',
+        'node_modules/@appscode/json2yaml/src/json2yaml.js',
         'node_modules/angular-ui-router/release/angular-ui-router.js',
         'node_modules/angular-ui-bootstrap/dist/ui-bootstrap-tpls.js',
-        'heat_dashboard/static/dashboard/project/heat_dashboard/template_generator/js/libs/*.js',
         'heat_dashboard/static/dashboard/project/heat_dashboard/template_generator/js/components/*.module.js',
         'heat_dashboard/static/dashboard/project/heat_dashboard/template_generator/js/components/!(*.spec|*.module).js',
         'heat_dashboard/static/dashboard/project/heat_dashboard/template_generator/js/components/*.spec.js',
